MIG algebraic rewriting
-----------------------

**Header:** ``mockturtle/algorithms/mig_algebraic_rewriting.hpp``

Parameters
~~~~~~~~~~

.. doxygenstruct:: mockturtle::mig_algebraic_depth_rewriting_params
   :members:

Algorithm
~~~~~~~~~

.. doxygenfunction:: mockturtle::mig_algebraic_depth_rewriting
